PyKEEN
======
.. automodule:: pykeen

.. toctree::
   :caption: Getting Started
   :name: quickstart
   :maxdepth: 2

   installation
   tutorial/first_steps
   tutorial/trackers/index
   tutorial/checkpoints
   tutorial/translational_toy_example
   tutorial/understanding_evaluation
   tutorial/running_hpo
   tutorial/making_predictions
   tutorial/running_ablation
   tutorial/performance
   tutorial/representations
   tutorial/node_piece
   tutorial/inductive_lp

.. toctree::
   :caption: Bring Your Own
   :name: byo
   :maxdepth: 2

   byo/data
   byo/interaction

.. toctree::
   :caption: Extending PyKEEN
   :name: extending
   :maxdepth: 2

   extending/datasets
   extending/models_new
   extending/models

.. toctree::
   :caption: Reference
   :name: reference
   :maxdepth: 2

   reference/pipeline
   reference/models
   reference/datasets
   reference/triples
   reference/training
   reference/stoppers
   reference/losses
   reference/regularizers
   reference/trackers
   reference/negative_sampling
   reference/evaluation
   reference/metrics
   reference/hpo
   reference/ablation
   reference/lookup
   reference/predict
   reference/uncertainty
   reference/sealant
   reference/constants
   reference/nn/index
   reference/utils

.. toctree::
   :caption: Appendix
   :name: appendix
   :maxdepth: 2

   references

Indices and Tables
------------------
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
